# -*- coding: utf-8 -*-
# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
""" Base interface for nitime """

from ..base import LibraryBaseInterface


class NitimeBaseInterface(LibraryBaseInterface):
    _pkg = "nitime"
